==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QEventLoopLocker_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qeventloop.h>
#include <QtCore/QVariant>
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QEventLoopLocker(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QEventLoopLocker")
    QEventLoopLocker *_ptr = reinterpret_cast<QEventLoopLocker *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QEventLoopLocker()
void __qt_construct_QEventLoopLocker_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEventLoopLocker()")
    Q_UNUSED(__java_arguments)
    QEventLoopLocker *__qt_this = new(__qtjambi_ptr) QEventLoopLocker();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QEventLoopLocker(QEventLoop*)
void __qt_construct_QEventLoopLocker_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEventLoopLocker(QEventLoop*)")
    jobject loop0 = __java_arguments[0].l;
    QEventLoop* __qt_loop0 = qtjambi_cast<QEventLoop* >(__jni_env, loop0);
    QEventLoopLocker *__qt_this = new(__qtjambi_ptr) QEventLoopLocker(__qt_loop0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QEventLoopLocker(QThread*)
void __qt_construct_QEventLoopLocker_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEventLoopLocker(QThread*)")
    jobject thread0 = __java_arguments[0].l;
    QThread* __qt_thread0 = qtjambi_cast<QThread* >(__jni_env, thread0);
    QEventLoopLocker *__qt_this = new(__qtjambi_ptr) QEventLoopLocker(__qt_thread0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QEventLoopLocker
void __qt_destruct_QEventLoopLocker(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QEventLoopLocker")
    reinterpret_cast<QEventLoopLocker*>(ptr)->~QEventLoopLocker();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QEventLoopLocker::QEventLoopLocker()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEventLoopLocker_initialize_1native__Lio_qt_core_QEventLoopLocker_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEventLoopLocker::QEventLoopLocker()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEventLoopLocker_0, sizeof(QEventLoopLocker), typeid(QEventLoopLocker), false, &deleter_QEventLoopLocker, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEventLoopLocker::QEventLoopLocker(QEventLoop*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEventLoopLocker_initialize_1native__Lio_qt_core_QEventLoopLocker_2Lio_qt_core_QEventLoop_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject loop0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEventLoopLocker::QEventLoopLocker(QEventLoop*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = loop0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEventLoopLocker_1, sizeof(QEventLoopLocker), typeid(QEventLoopLocker), false, &deleter_QEventLoopLocker, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEventLoopLocker::QEventLoopLocker(QThread*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEventLoopLocker_initialize_1native__Lio_qt_core_QEventLoopLocker_2Lio_qt_core_QThread_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject thread0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEventLoopLocker::QEventLoopLocker(QThread*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = thread0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEventLoopLocker_2, sizeof(QEventLoopLocker), typeid(QEventLoopLocker), false, &deleter_QEventLoopLocker, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QEventLoopLocker(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QEventLoopLocker>("QEventLoopLocker", "io/qt/core/QEventLoopLocker");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QEventLoopLocker, {
        ConstructorInfo(&__qt_construct_QEventLoopLocker_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QEventLoopLocker_1, "Lio/qt/core/QEventLoop;")
       ,ConstructorInfo(&__qt_construct_QEventLoopLocker_2, "Lio/qt/core/QThread;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QEventLoopLocker);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QEventLoopLocker_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qeventloop.h>
#include <QtCore/QVariant>
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QEventLoopLocker(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QEventLoopLocker")
    QEventLoopLocker *_ptr = reinterpret_cast<QEventLoopLocker *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QEventLoopLocker()
void __qt_construct_QEventLoopLocker(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEventLoopLocker()")
    Q_UNUSED(__java_arguments)
    QEventLoopLocker *__qt_this = new(__qtjambi_ptr) QEventLoopLocker();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QEventLoopLocker::QEventLoopLocker()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEventLoopLocker_initialize_1native__Lio_qt_core_QEventLoopLocker_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEventLoopLocker::QEventLoopLocker()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEventLoopLocker, sizeof(QEventLoopLocker), typeid(QEventLoopLocker), 0, false, &deleter_QEventLoopLocker, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QEventLoopLocker(QEventLoop*)
void __qt_construct_QEventLoopLocker_QEventLoop_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEventLoopLocker(QEventLoop*)")
    jobject loop0 = __java_arguments[0].l;
    QEventLoop* __qt_loop0 = qtjambi_cast<QEventLoop*>(__jni_env, loop0);
    QEventLoopLocker *__qt_this = new(__qtjambi_ptr) QEventLoopLocker(__qt_loop0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QEventLoopLocker::QEventLoopLocker(QEventLoop*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEventLoopLocker_initialize_1native__Lio_qt_core_QEventLoopLocker_2Lio_qt_core_QEventLoop_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject loop0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEventLoopLocker::QEventLoopLocker(QEventLoop*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = loop0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEventLoopLocker_QEventLoop_ptr, sizeof(QEventLoopLocker), typeid(QEventLoopLocker), 0, false, &deleter_QEventLoopLocker, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QEventLoopLocker(QThread*)
void __qt_construct_QEventLoopLocker_QThread_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEventLoopLocker(QThread*)")
    jobject thread0 = __java_arguments[0].l;
    QThread* __qt_thread0 = qtjambi_cast<QThread*>(__jni_env, thread0);
    QEventLoopLocker *__qt_this = new(__qtjambi_ptr) QEventLoopLocker(__qt_thread0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QEventLoopLocker::QEventLoopLocker(QThread*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEventLoopLocker_initialize_1native__Lio_qt_core_QEventLoopLocker_2Lio_qt_core_QThread_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject thread0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEventLoopLocker::QEventLoopLocker(QThread*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = thread0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEventLoopLocker_QThread_ptr, sizeof(QEventLoopLocker), typeid(QEventLoopLocker), 0, false, &deleter_QEventLoopLocker, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QEventLoopLocker
void __qt_destruct_QEventLoopLocker(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QEventLoopLocker")
    reinterpret_cast<QEventLoopLocker*>(ptr)->~QEventLoopLocker();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QEventLoopLocker(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QEventLoopLocker>("QEventLoopLocker", "io/qt/core/QEventLoopLocker");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QEventLoopLocker, {
        ConstructorInfo(&__qt_construct_QEventLoopLocker, nullptr)
       ,ConstructorInfo(&__qt_construct_QEventLoopLocker_QEventLoop_ptr, "Lio/qt/core/QEventLoop;")
       ,ConstructorInfo(&__qt_construct_QEventLoopLocker_QThread_ptr, "Lio/qt/core/QThread;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QEventLoopLocker);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
